@@ -10,7 +10,8 @@ from .pl import plot_deg, plot_marker_exp
 from .pl import plot_cnv, plot_violin, plot_pct_box
 from .pl import get_sample_to_group_map, plot_sankey
 from .pl import get_population, get_cci_means, get_gene_expression_mean
-from .pl import get_markers_from_deg, test_group_diff, filter_gsa_result, find_condition_specific_markers
+from .pl import get_markers_from_deg, test_group_diff, filter_gsa_result
+from .pl import find_condition_specific_markers, find_tumor_origin
 from .pl import find_genomic_spots_of_cnv_peaks, find_genes_in_genomic_spots, plot_cnv
 from .pl import find_signif_CNV_gain_regions, check_cnv_hit, plot_cnv_hit, plot_cnv_stat
-from .load_data import load_sample_data
+from .load_data import load_sample_data, load_scoda_processed_sample_data
